@@ -38,20 +38,20 @@ string_to_base64 (const char *message)
     return NULL;
   tmp[0] = 0;
   for (i = 0; i < length; i += 3)
-    {
-      l = (((unsigned long) message[i]) << 16)
+  {
+    l = (((unsigned long) message[i]) << 16)
         | (((i + 1) < length) ? (((unsigned long) message[i + 1]) << 8) : 0)
         | (((i + 2) < length) ? ((unsigned long) message[i + 2]) : 0);
 
 
-      strncat (tmp, &lookup[(l >> 18) & 0x3F], 1);
-      strncat (tmp, &lookup[(l >> 12) & 0x3F], 1);
+    strncat (tmp, &lookup[(l >> 18) & 0x3F], 1);
+    strncat (tmp, &lookup[(l >> 12) & 0x3F], 1);
 
-      if (i + 1 < length)
-        strncat (tmp, &lookup[(l >> 6) & 0x3F], 1);
-      if (i + 2 < length)
-        strncat (tmp, &lookup[l & 0x3F], 1);
-    }
+    if (i + 1 < length)
+      strncat (tmp, &lookup[(l >> 6) & 0x3F], 1);
+    if (i + 2 < length)
+      strncat (tmp, &lookup[l & 0x3F], 1);
+  }
 
   if (length % 3)
     strncat (tmp, "===", 3 - length % 3);
@@ -67,16 +67,16 @@ get_file_size (const char *filename)
 
   fp = fopen (filename, "rb");
   if (fp)
-    {
-      long size;
+  {
+    long size;
 
-      if ((0 != fseek (fp, 0, SEEK_END)) || (-1 == (size = ftell (fp))))
-        size = 0;
+    if ((0 != fseek (fp, 0, SEEK_END)) || (-1 == (size = ftell (fp))))
+      size = 0;
 
-      fclose (fp);
+    fclose (fp);
 
-      return size;
-    }
+    return size;
+  }
   else
     return 0;
 }
@@ -99,58 +99,58 @@ load_file (const char *filename)
 
   buffer = malloc (size + 1);
   if (! buffer)
-    {
-      fclose (fp);
-      return NULL;
-    }
+  {
+    fclose (fp);
+    return NULL;
+  }
   buffer[size] = '\0';
 
-  if (size != (long)fread (buffer, 1, size, fp))
-    {
-      free (buffer);
-      buffer = NULL;
-    }
+  if (size != (long) fread (buffer, 1, size, fp))
+  {
+    free (buffer);
+    buffer = NULL;
+  }
 
   fclose (fp);
   return buffer;
 }
 
 
-static int
+static enum MHD_Result
 ask_for_authentication (struct MHD_Connection *connection, const char *realm)
 {
-  int ret;
+  enum MHD_Result ret;
   struct MHD_Response *response;
   char *headervalue;
   size_t slen;
   const char *strbase = "Basic realm=";
 
   response = MHD_create_response_from_buffer (0, NULL,
-					      MHD_RESPMEM_PERSISTENT);
-  if (!response)
+                                              MHD_RESPMEM_PERSISTENT);
+  if (! response)
     return MHD_NO;
 
   slen = strlen (strbase) + strlen (realm) + 1;
   if (NULL == (headervalue = malloc (slen)))
     return MHD_NO;
   snprintf (headervalue,
-	    slen,
-	    "%s%s",
-	    strbase,
-	    realm);
+            slen,
+            "%s%s",
+            strbase,
+            realm);
   ret = MHD_add_response_header (response,
-				 "WWW-Authenticate",
-				 headervalue);
+                                 "WWW-Authenticate",
+                                 headervalue);
   free (headervalue);
   if (! ret)
-    {
-      MHD_destroy_response (response);
-      return MHD_NO;
-    }
+  {
+    MHD_destroy_response (response);
+    return MHD_NO;
+  }
 
   ret = MHD_queue_response (connection,
-			    MHD_HTTP_UNAUTHORIZED,
-			    response);
+                            MHD_HTTP_UNAUTHORIZED,
+                            response);
   MHD_destroy_response (response);
   return ret;
 }
@@ -159,7 +159,7 @@ ask_for_authentication (struct MHD_Connection *connection, const char *realm)
 static int
 is_authenticated (struct MHD_Connection *connection,
                   const char *username,
-		  const char *password)
+                  const char *password)
 {
   const char *headervalue;
   char *expected_b64;
@@ -180,10 +180,10 @@ is_authenticated (struct MHD_Connection *connection,
   if (NULL == (expected = malloc (slen)))
     return 0;
   snprintf (expected,
-	    slen,
-	    "%s:%s",
-	    username,
-	    password);
+            slen,
+            "%s:%s",
+            username,
+            password);
   expected_b64 = string_to_base64 (expected);
   free (expected);
   if (NULL == expected_b64)
@@ -196,17 +196,17 @@ is_authenticated (struct MHD_Connection *connection,
 }
 
 
-static int
+static enum MHD_Result
 secret_page (struct MHD_Connection *connection)
 {
-  int ret;
+  enum MHD_Result ret;
   struct MHD_Response *response;
   const char *page = "<html><body>A secret.</body></html>";
 
   response =
     MHD_create_response_from_buffer (strlen (page), (void *) page,
-				     MHD_RESPMEM_PERSISTENT);
-  if (!response)
+                                     MHD_RESPMEM_PERSISTENT);
+  if (! response)
     return MHD_NO;
 
   ret = MHD_queue_response (connection, MHD_HTTP_OK, response);
@@ -216,27 +216,27 @@ secret_page (struct MHD_Connection *connection)
 }
 
 
-static int
+static enum MHD_Result
 answer_to_connection (void *cls, struct MHD_Connection *connection,
                       const char *url, const char *method,
                       const char *version, const char *upload_data,
                       size_t *upload_data_size, void **con_cls)
 {
-  (void)cls;               /* Unused. Silent compiler warning. */
-  (void)url;               /* Unused. Silent compiler warning. */
-  (void)version;           /* Unused. Silent compiler warning. */
-  (void)upload_data;       /* Unused. Silent compiler warning. */
-  (void)upload_data_size;  /* Unused. Silent compiler warning. */
+  (void) cls;               /* Unused. Silent compiler warning. */
+  (void) url;               /* Unused. Silent compiler warning. */
+  (void) version;           /* Unused. Silent compiler warning. */
+  (void) upload_data;       /* Unused. Silent compiler warning. */
+  (void) upload_data_size;  /* Unused. Silent compiler warning. */
 
   if (0 != strcmp (method, "GET"))
     return MHD_NO;
   if (NULL == *con_cls)
-    {
-      *con_cls = connection;
-      return MHD_YES;
-    }
+  {
+    *con_cls = connection;
+    return MHD_YES;
+  }
 
-  if (!is_authenticated (connection, USER, PASSWORD))
+  if (! is_authenticated (connection, USER, PASSWORD))
     return ask_for_authentication (connection, REALM);
 
   return secret_page (connection);
@@ -254,14 +254,14 @@ main ()
   cert_pem = load_file (SERVERCERTFILE);
 
   if ((key_pem == NULL) || (cert_pem == NULL))
-    {
-      printf ("The key/certificate files could not be read.\n");
-      if (NULL != key_pem)
-        free (key_pem);
-      if (NULL != cert_pem)
-        free (cert_pem);
-      return 1;
-    }
+  {
+    printf ("The key/certificate files could not be read.\n");
+    if (NULL != key_pem)
+      free (key_pem);
+    if (NULL != cert_pem)
+      free (cert_pem);
+    return 1;
+  }
 
   daemon =
     MHD_start_daemon (MHD_USE_INTERNAL_POLLING_THREAD | MHD_USE_TLS, PORT, NULL,
@@ -269,14 +269,14 @@ main ()
                       MHD_OPTION_HTTPS_MEM_KEY, key_pem,
                       MHD_OPTION_HTTPS_MEM_CERT, cert_pem, MHD_OPTION_END);
   if (NULL == daemon)
-    {
-      printf ("%s\n", cert_pem);
+  {
+    printf ("%s\n", cert_pem);
 
-      free (key_pem);
-      free (cert_pem);
+    free (key_pem);
+    free (cert_pem);
 
-      return 1;
-    }
+    return 1;
+  }
 
   (void) getchar ();
 
