@@ -207,7 +207,7 @@ static magic_t magic;
 
 
 /**
- * Mark the given response as HTML for the brower.
+ * Mark the given response as HTML for the browser.
  *
  * @param response response to mark
  */
@@ -267,7 +267,7 @@ struct ResponseDataContext
  * @param dirname name of the directory to list
  * @return MHD_YES on success, MHD_NO on error
  */
-static int
+static enum MHD_Result
 list_directory (struct ResponseDataContext *rdc,
                 const char *dirname)
 {
@@ -447,7 +447,7 @@ struct UploadContext
  * @param size number of bytes in 'data'
  * @return #MHD_NO on allocation failure, #MHD_YES on success
  */
-static int
+static enum MHD_Result
 do_append (char **ret,
            const char *data,
            size_t size)
@@ -493,10 +493,10 @@ do_append (char **ret,
  *              specified offset
  * @param off offset of data in the overall value
  * @param size number of bytes in data available
- * @return MHD_YES to continue iterating,
- *         MHD_NO to abort the iteration
+ * @return #MHD_YES to continue iterating,
+ *         #MHD_NO to abort the iteration
  */
-static int
+static enum MHD_Result
 process_upload_data (void *cls,
                      enum MHD_ValueKind kind,
                      const char *key,
@@ -527,7 +527,7 @@ process_upload_data (void *cls,
   }
   if (NULL == filename)
   {
-    fprintf (stderr, "No filename, aborting upload\n");
+    fprintf (stderr, "No filename, aborting upload.\n");
     return MHD_NO;   /* no filename, error */
   }
   if ( (NULL == uc->category) ||
@@ -667,10 +667,10 @@ response_completed_callback (void *cls,
  * @param connection connection to return the directory for
  * @return MHD_YES on success, MHD_NO on error
  */
-static int
+static enum MHD_Result
 return_directory_response (struct MHD_Connection *connection)
 {
-  int ret;
+  enum MHD_Result ret;
 
   (void) pthread_mutex_lock (&mutex);
   if (NULL == cached_directory_response)
@@ -699,7 +699,7 @@ return_directory_response (struct MHD_Connection *connection)
  * @param ptr our context
  * @return #MHD_YES on success, #MHD_NO to drop connection
  */
-static int
+static enum MHD_Result
 generate_page (void *cls,
                struct MHD_Connection *connection,
                const char *url,
@@ -709,7 +709,7 @@ generate_page (void *cls,
                size_t *upload_data_size, void **ptr)
 {
   struct MHD_Response *response;
-  int ret;
+  enum MHD_Result ret;
   int fd;
   struct stat buf;
   (void) cls;               /* Unused. Silent compiler warning. */
@@ -1001,7 +1001,7 @@ main (int argc, char *const *argv)
                         MHD_OPTION_END);
   if (NULL == d)
     return 1;
-  fprintf (stderr, "HTTP server running. Press ENTER to stop the server\n");
+  fprintf (stderr, "HTTP server running. Press ENTER to stop the server.\n");
   (void) getc (stdin);
   MHD_stop_daemon (d);
   MHD_destroy_response (file_not_found_response);
