@@ -41,7 +41,7 @@
 #define S_ISREG(x) (S_IFREG == (x & S_IFREG))
 #endif /* S_ISREG */
 
-static int
+static enum MHD_Result
 ahc_echo (void *cls,
           struct MHD_Connection *connection,
           const char *url,
@@ -52,7 +52,7 @@ ahc_echo (void *cls,
 {
   static int aptr;
   struct MHD_Response *response;
-  int ret;
+  enum MHD_Result ret;
   int fd;
   struct stat buf;
   (void) cls;               /* Unused. Silent compiler warning. */
