@@ -279,7 +279,7 @@ wr_create_from_plain_sckt (MHD_socket plain_sk)
  * Connect socket to specified address.
  * @param s socket to use
  * @param addr address to connect
- * @param length of sturcture pointed by @a addr
+ * @param length of structure pointed by @a addr
  * @return zero on success, -1 otherwise.
  */
 static int
@@ -840,10 +840,10 @@ upgrade_cb (void *cls,
  *        can be set with the #MHD_OPTION_NOTIFY_COMPLETED).
  *        Initially, `*con_cls` will be NULL.
  * @return #MHD_YES if the connection was handled successfully,
- *         #MHD_NO if the socket must be closed due to a serios
+ *         #MHD_NO if the socket must be closed due to a serious
  *         error while handling the request
  */
-static int
+static enum MHD_Result
 ahc_upgrade (void *cls,
              struct MHD_Connection *connection,
              const char *url,
@@ -854,7 +854,7 @@ ahc_upgrade (void *cls,
              void **con_cls)
 {
   struct MHD_Response *resp;
-  int ret;
+  enum MHD_Result ret;
   (void) cls;
   (void) url;
   (void) method;                        /* Unused. Silent compiler warning. */
