@@ -134,7 +134,7 @@ copyBuffer (void *ptr,
 }
 
 
-static int
+static enum MHD_Result
 ahc_echo (void *cls,
           struct MHD_Connection *connection,
           const char *url,
@@ -146,7 +146,7 @@ ahc_echo (void *cls,
 {
   static int ptr;
   const char *me = cls;
-  int ret;
+  enum MHD_Result ret;
   (void) url; (void) version;                      /* Unused. Silent compiler warning. */
   (void) upload_data; (void) upload_data_size;     /* Unused. Silent compiler warning. */
 
